@@ -1,11 +1,11 @@
-import numpy as np
-import cloudpickle as pickle
-from sortedcontainers import SortedListWithKey
 import abc
 
+import cloudpickle as pickle
+import numpy as np
+from sortedcontainers import SortedListWithKey
+
 
 class EPSMixin(abc.ABC):
-
     def full_submit_function_pickle(self, job_id):
         simulate_one = pickle.loads(self.simulate_accept_one)
         result_batch = []
@@ -16,8 +16,15 @@ class EPSMixin(abc.ABC):
         return result_batch
 
     def sample_until_n_accepted(
-            self, n, simulate_one, t, *,
-            max_eval=np.inf, all_accepted=False, ana_vars=None):
+        self,
+        n,
+        simulate_one,
+        t,
+        *,
+        max_eval=np.inf,
+        all_accepted=False,
+        ana_vars=None,
+    ):
         # For default pickling
         if self.default_pickle:
             self.simulate_accept_one = pickle.dumps(simulate_one)
@@ -56,8 +63,9 @@ class EPSMixin(abc.ABC):
                         remote_accept = remote_evaluated[1]
                         remote_jobid = remote_evaluated[2]
                         # print("Received result on job ", remote_jobid)
-                        unprocessed_results.add((remote_jobid, remote_accept,
-                                                 remote_result))
+                        unprocessed_results.add(
+                            (remote_jobid, remote_accept, remote_result)
+                        )
                         if remote_accept:
                             num_accepted_total += 1
 
@@ -65,7 +73,7 @@ class EPSMixin(abc.ABC):
                 next_index = unprocessed_results[0][0]
             else:
                 next_index = np.nan
-            while next_index == next_valid_index+1:
+            while next_index == next_valid_index + 1:
                 seq_evaluated = unprocessed_results.pop(0)
                 # add to all_results
                 all_results.add((seq_evaluated[0], seq_evaluated[2]))
@@ -89,21 +97,28 @@ class EPSMixin(abc.ABC):
             # Number of jobs open < self.scheduler_workers_running *
             # worker_load_factor
             # num_accepted_total < jobs required
-            if (len(running_jobs) < self.client_max_jobs) and \
-                    (len(running_jobs) < self.client_cores()) and \
-                    (num_accepted_total < n):
-                for _ in range(0,
-                               np.minimum(self.client_max_jobs,
-                                          self.client_cores()).astype(int)
-                               - len(running_jobs)):
+            if (
+                (len(running_jobs) < self.client_max_jobs)
+                and (len(running_jobs) < self.client_cores())
+                and (num_accepted_total < n)
+            ):
+                for _ in range(
+                    0,
+                    np.minimum(
+                        self.client_max_jobs, self.client_cores()
+                    ).astype(int)
+                    - len(running_jobs),
+                ):
                     job_id_batch = []
                     for _ in range(self.batch_size):
                         job_id_batch.append(next_job_id)
                         next_job_id += 1
 
                     running_jobs.append(
-                        self.my_client.submit(full_submit_function,
-                                              job_id_batch))
+                        self.my_client.submit(
+                            full_submit_function, job_id_batch
+                        )
+                    )
 
         # cancel all unfinished jobs
         for curJob in running_jobs:
