@@ -1,25 +1,36 @@
-import socket
-from redis import StrictRedis
-import os
-from time import time
-import click
-from multiprocessing import Process
-import numpy as np
-import random
 import logging
+import os
+import random
+import socket
+from multiprocessing import Process
+from time import time
 
-from .cmd import (N_EVAL, N_ACC, N_REQ, N_WORKER, START, STOP, MSG,
-                  ANALYSIS_ID, GENERATION, MODE, DYNAMIC, STATIC, idfy)
+import click
+import numpy as np
+from redis import StrictRedis
+
+from .cmd import (
+    ANALYSIS_ID,
+    DYNAMIC,
+    GENERATION,
+    MODE,
+    MSG,
+    N_ACC,
+    N_EVAL,
+    N_REQ,
+    N_WORKER,
+    START,
+    STATIC,
+    STOP,
+    idfy,
+)
 from .util import KillHandler
 from .work import work_on_population_dynamic
 from .work_static import work_on_population_static
 
 logger = logging.getLogger("ABC.Sampler")
 
-TIMES = {"s": 1,
-         "m": 60,
-         "h": 3600,
-         "d":  24*3600}
+TIMES = {"s": 1, "m": 60, "h": 3600, "d": 24 * 3600}
 
 
 def runtime_parse(s):
@@ -31,26 +42,45 @@ def runtime_parse(s):
 @click.command(help="Evaluation parallel redis sampler for pyABC.")
 @click.option('--host', default="localhost", help='Redis host.')
 @click.option('--port', default=6379, type=int, help='Redis port.')
-@click.option('--runtime', default="2h", type=str,
-              help='Max worker runtime if the form <NR><UNIT>, '
-                   'where <NR> is any number and <UNIT> can be s, '
-                   '(S,) m, (M,) '
-                   'h, (H,) d, (D) for seconds, minutes, hours and days. '
-                   'E.g. for 12 hours you would pass --runtime=12h, for half '
-                   'a day you could do 0.5d.')
-@click.option('--password', default=None, type=str,
-              help='Password for a secure connection.')
-@click.option('--processes', default=1, type=int,
-              help="The number of worker processes to start")
-@click.option('--daemon', default=True, type=bool,
-              help="Create subprocesses in daemon mode.")
+@click.option(
+    '--runtime',
+    default="2h",
+    type=str,
+    help='Max worker runtime if the form <NR><UNIT>, '
+    'where <NR> is any number and <UNIT> can be s, '
+    '(S,) m, (M,) '
+    'h, (H,) d, (D) for seconds, minutes, hours and days. '
+    'E.g. for 12 hours you would pass --runtime=12h, for half '
+    'a day you could do 0.5d.',
+)
+@click.option(
+    '--password',
+    default=None,
+    type=str,
+    help='Password for a secure connection.',
+)
+@click.option(
+    '--processes',
+    default=1,
+    type=int,
+    help="The number of worker processes to start",
+)
+@click.option(
+    '--daemon',
+    default=True,
+    type=bool,
+    help="Create subprocesses in daemon mode.",
+)
 @click.option('--catch', default=True, type=bool, help="Catch errors.")
-def work(host="localhost",
-         port=6379, runtime="2h",
-         password=None,
-         processes=1,
-         daemon=True,
-         catch=True):
+def work(
+    host="localhost",
+    port=6379,
+    runtime="2h",
+    password=None,
+    processes=1,
+    daemon=True,
+    catch=True,
+):
     """Start workers.
     Corresponds to the entry point abc-redis-worker.
     """
@@ -60,10 +90,13 @@ def work(host="localhost",
 
     # define parallel processes
     procs = [
-        Process(target=_work,
-                args=(host, port, runtime, password, catch),
-                daemon=daemon)
-        for _ in range(processes)]
+        Process(
+            target=_work,
+            args=(host, port, runtime, password, catch),
+            daemon=daemon,
+        )
+        for _ in range(processes)
+    ]
 
     # start them
     for proc in procs:
@@ -78,8 +111,9 @@ def work(host="localhost",
         proc.join()
 
 
-def _work(host="localhost", port=6379, runtime="2h", password=None,
-          catch=True):
+def _work(
+    host="localhost", port=6379, runtime="2h", password=None, catch=True
+):
     np.random.seed()
     random.seed()
 
@@ -89,7 +123,8 @@ def _work(host="localhost", port=6379, runtime="2h", password=None,
     max_runtime_s = runtime_parse(runtime)
     logger.info(
         f"Start redis worker. Max run time {max_runtime_s}s, "
-        f"HOST={socket.gethostname()}, PID={os.getpid()}")
+        f"HOST={socket.gethostname()}, PID={os.getpid()}"
+    )
 
     # connect to the redis server
     redis = StrictRedis(host=host, port=port, password=password)
@@ -137,14 +172,24 @@ def _work(host="localhost", port=6379, runtime="2h", password=None,
             # work on the specified population in dynamic or static mode
             if mode == DYNAMIC:
                 work_on_population_dynamic(
-                    analysis_id=analysis_id, t=t,
-                    redis=redis, catch=catch, start_time=start_time,
-                    max_runtime_s=max_runtime_s, kill_handler=kill_handler)
+                    analysis_id=analysis_id,
+                    t=t,
+                    redis=redis,
+                    catch=catch,
+                    start_time=start_time,
+                    max_runtime_s=max_runtime_s,
+                    kill_handler=kill_handler,
+                )
             elif mode == STATIC:
                 work_on_population_static(
-                    analysis_id=analysis_id, t=t,
-                    redis=redis, catch=catch, start_time=start_time,
-                    max_runtime_s=max_runtime_s, kill_handler=kill_handler)
+                    analysis_id=analysis_id,
+                    t=t,
+                    redis=redis,
+                    catch=catch,
+                    start_time=start_time,
+                    max_runtime_s=max_runtime_s,
+                    kill_handler=kill_handler,
+                )
             else:
                 # this should never happen
                 raise ValueError(f"Did not recognize mode {mode}")
@@ -159,26 +204,31 @@ def _work(host="localhost", port=6379, runtime="2h", password=None,
         elapsed_time = time() - start_time
         if elapsed_time > max_runtime_s:
             logger.info(
-                "Shutdown redis worker. Max runtime {}s reached"
-                .format(max_runtime_s))
+                "Shutdown redis worker. Max runtime {}s reached".format(
+                    max_runtime_s
+                )
+            )
             return
 
 
-@click.command(help="ABC Redis cluster manager. "
-                    "The command can be 'info' or 'stop'. "
-                    "For 'stop' the workers are shut down cleanly "
-                    "after the current population. "
-                    "For 'info' you'll see how many workers are connected, "
-                    "how many evaluations the current population has, and "
-                    "how many particles are still missing. "
-                    "For 'reset-workers', the worker count will be resetted to"
-                    "zero. This does not cancel the sampling. This is useful "
-                    "if workers were unexpectedly killed.")
+@click.command(
+    help="ABC Redis cluster manager. "
+    "The command can be 'info' or 'stop'. "
+    "For 'stop' the workers are shut down cleanly "
+    "after the current population. "
+    "For 'info' you'll see how many workers are connected, "
+    "how many evaluations the current population has, and "
+    "how many particles are still missing. "
+    "For 'reset-workers', the worker count will be resetted to"
+    "zero. This does not cancel the sampling. This is useful "
+    "if workers were unexpectedly killed."
+)
 @click.option('--host', default="localhost", help="Redis host.")
 @click.option('--port', default=6379, type=int, help="Redis port.")
 @click.option('--password', default=None, type=str, help="Redis password.")
-@click.option('--time', '-t', 't', default=None, type=int,
-              help="Generation t.")
+@click.option(
+    '--time', '-t', 't', default=None, type=int, help="Generation t."
+)
 @click.argument('command', type=str)
 def manage(command, host="localhost", port=6379, password=None, t=None):
     """Manage workers.
@@ -211,13 +261,19 @@ def _manage(command, host="localhost", port=6379, password=None, t=None):
 
     if command == "info":
         pipeline = redis.pipeline()
-        res = (pipeline.get(idfy(N_WORKER, ana_id, t))
-               .get(idfy(N_EVAL, ana_id, t))
-               .get(idfy(N_ACC, ana_id, t))
-               .get(idfy(N_REQ, ana_id, t)).execute())
+        res = (
+            pipeline.get(idfy(N_WORKER, ana_id, t))
+            .get(idfy(N_EVAL, ana_id, t))
+            .get(idfy(N_ACC, ana_id, t))
+            .get(idfy(N_REQ, ana_id, t))
+            .execute()
+        )
         res = [r.decode() if r is not None else r for r in res]
-        print("Workers={} Evaluations={} Acceptances={}/{} (generation {})"
-              .format(*res, t))
+        print(
+            "Workers={} Evaluations={} Acceptances={}/{} (generation {})".format(
+                *res, t
+            )
+        )
     elif command == "reset-workers":
         redis.set(idfy(N_WORKER, ana_id, t), 0)
 
