@@ -1,6 +1,6 @@
 import pytest
 
-from pyabc.distance import to_distance
+from pyabc.distance import FunctionDistance
 
 
 def f(x, y):
@@ -13,6 +13,6 @@ def distance(request):
 
 
 def test_distance_none(distance):
-    dist_func = to_distance(distance)
+    dist_func = FunctionDistance.to_distance(distance)
     config = dist_func.get_config()
     assert "name" in config
